@@ -605,7 +605,9 @@ std::string pqxx::connection::encrypt_password(
       throw feature_not_supported{
         "Could not encrypt password: available libpq version does not support "
         "algorithms other than md5."};
+#  include "pqxx/internal/ignore-deprecated-pre.hxx"
     return pqxx::encrypt_password(user, password);
+#  include "pqxx/internal/ignore-deprecated-post.hxx"
   }
 #endif // PQXX_HAVE_PQENCRYPTPASSWORDCONN
 }
@@ -635,14 +637,15 @@ void pqxx::connection::unprepare(std::string_view name)
 
 
 pqxx::result pqxx::connection::exec_prepared(
-  std::string_view statement, internal::params const &args)
+  std::string_view statement, internal::c_params const &args)
 {
-  auto const pointers{args.get_pointers()};
   auto const q{std::make_shared<std::string>(statement)};
   auto const pq_result{PQexecPrepared(
     m_conn, q->c_str(),
-    check_cast<int>(std::size(args.nonnulls), "exec_prepared"sv),
-    pointers.data(), args.lengths.data(), args.binaries.data(), 0)};
+    check_cast<int>(std::size(args.values), "exec_prepared"sv),
+    args.values.data(), args.lengths.data(),
+    reinterpret_cast<int const *>(args.formats.data()),
+    static_cast<int>(format::text))};
   auto const r{make_result(pq_result, q, statement)};
   get_notifs();
   return r;
@@ -760,8 +763,8 @@ pqxx::connection::read_copy_line()
 void pqxx::connection::write_copy_line(std::string_view line)
 {
   static std::string const err_prefix{"Error writing to table: "};
-  // TODO: Use C++20's ssize().
-  auto const size{check_cast<int>(std::size(line), "write_copy_line()"sv)};
+  auto const size{check_cast<int>(
+    internal::ssize(line), "Line in stream_to is too long to process."sv)};
   if (PQputCopyData(m_conn, line.data(), size) <= 0)
     throw failure{err_prefix + err_msg()};
   if (PQputCopyData(m_conn, "\n", 1) <= 0)
@@ -865,9 +868,9 @@ std::string pqxx::connection::unesc_raw(char const text[]) const
 std::string
 pqxx::connection::quote_raw(unsigned char const bin[], std::size_t len) const
 {
-#include "pqxx/internal/ignore-deprecated-pre.hxx"
-  return internal::concat("'", esc_raw(bin, len), "'::bytea");
-#include "pqxx/internal/ignore-deprecated-post.hxx"
+  std::basic_string_view<std::byte> view{
+    reinterpret_cast<std::byte const *>(bin), len};
+  return internal::concat("'", esc_raw(view), "'::bytea");
 }
 
 
@@ -880,15 +883,13 @@ pqxx::connection::quote_raw(std::basic_string_view<std::byte> bytes) const
 
 std::string pqxx::connection::quote(binarystring const &b) const
 {
-#include "pqxx/internal/ignore-deprecated-pre.hxx"
-  return quote_raw(b.data(), std::size(b));
-#include "pqxx/internal/ignore-deprecated-post.hxx"
+  return quote(b.bytes_view());
 }
 
 
 std::string pqxx::connection::quote(std::basic_string_view<std::byte> b) const
 {
-  return quote_raw(b);
+  return internal::concat("'", esc_raw(b), "'::bytea");
 }
 
 
@@ -903,6 +904,20 @@ std::string pqxx::connection::quote_name(std::string_view identifier) const
 }
 
 
+std::string pqxx::connection::quote_table(std::string_view table_name) const
+{
+  return this->quote_name(table_name);
+}
+
+
+std::string pqxx::connection::quote_table(table_path path) const
+{
+  return separated_list(
+    ".", std::begin(path), std::end(path),
+    [this](auto name) { return this->quote_name(*name); });
+}
+
+
 std::string
 pqxx::connection::esc_like(std::string_view text, char escape_char) const
 {
@@ -1100,15 +1115,15 @@ int pqxx::connection::encoding_id() const
 
 
 pqxx::result pqxx::connection::exec_params(
-  std::string_view query, internal::params const &args)
+  std::string_view query, internal::c_params const &args)
 {
-  auto const pointers{args.get_pointers()};
   auto const q{std::make_shared<std::string>(query)};
-  auto const nonnulls{
-    check_cast<int>(std::size(args.nonnulls), "exec_params() parameters"sv)};
   auto const pq_result{PQexecParams(
-    m_conn, q->c_str(), nonnulls, nullptr, pointers.data(),
-    args.lengths.data(), args.binaries.data(), 0)};
+    m_conn, q->c_str(),
+    check_cast<int>(std::size(args.values), "exec_params"sv), nullptr,
+    args.values.data(), args.lengths.data(),
+    reinterpret_cast<int const *>(args.formats.data()),
+    static_cast<int>(format::text))};
   auto const r{make_result(pq_result, q)};
   get_notifs();
   return r;
