@@ -264,18 +264,18 @@ namespace
 template<typename TYPE>
 [[maybe_unused]] inline TYPE from_string_arithmetic(std::string_view in)
 {
-  char const *begin;
+  char const *here;
+  auto const end{in.data() + std::size(in)};
 
   // Skip whitespace.  This is not the proper way to do it, but I see no way
   // that any of the supported encodings could ever produce a valid character
   // whose byte sequence would confuse this code.
-  for (begin = in.data();
-       begin < std::end(in) and (*begin == ' ' or *begin == '\t'); ++begin)
+  for (here = in.data(); here < end and (*here == ' ' or *here == '\t');
+       ++here)
     ;
 
-  auto const end{in.data() + std::size(in)};
   TYPE out;
-  auto const res{std::from_chars(begin, end, out)};
+  auto const res{std::from_chars(here, end, out)};
   if (res.ec == std::errc() and res.ptr == end)
     return out;
 
@@ -535,7 +535,7 @@ template<typename T> inline T from_string_awful_float(std::string_view text)
     }
     else
     {
-      if (have_thread_local)
+      if constexpr (have_thread_local)
       {
         thread_local dumb_stringstream<T> S;
         // Visual Studio 2017 seems to fail on repeated conversions if the
@@ -653,7 +653,7 @@ template<typename T> std::string to_string_float(T value)
     // In this rare case, we can convert to std::string but not to a simple
     // buffer.  So, implement to_buf in terms of to_string instead of the other
     // way around.
-    if (have_thread_local)
+    if constexpr (have_thread_local)
     {
       thread_local dumb_stringstream<T> s;
       return to_dumb_stringstream(s, value);
